var NAVTREEINDEX6 =
{
"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9":[6,22,59],
"group__API__Modularized__Scheduler.html#ga6b1f65158357aae0d9239063e54f82a4":[6,22,21],
"group__API__Modularized__Scheduler.html#ga70c74dee688684fb09e45833094ba21a":[6,22,27],
"group__API__Modularized__Scheduler.html#ga72554d14205573f57631b850afa3f39f":[6,22,11],
"group__API__Modularized__Scheduler.html#ga752889050651f6e3c83ddd2c3f96c0ff":[6,22,64],
"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8":[6,22,61],
"group__API__Modularized__Scheduler.html#ga79594b4403678fa1d6aa08f7fbe6e525":[6,22,45],
"group__API__Modularized__Scheduler.html#ga795d692f797ef022c350c9b5922cec31":[6,22,41],
"group__API__Modularized__Scheduler.html#ga7bacda898bdd7964b21ce611c7db077b":[6,22,10],
"group__API__Modularized__Scheduler.html#ga7ceaaeea8cc10f6d67706c4ee33e93ce":[6,22,37],
"group__API__Modularized__Scheduler.html#ga813c6be6ae07ec5fe6e54a1bd97267ce":[6,22,22],
"group__API__Modularized__Scheduler.html#ga862bc72530533cc7eab28294676f5318":[6,22,56],
"group__API__Modularized__Scheduler.html#ga87785b9c9eeb3718d85dc1b2a24fab26":[6,22,29],
"group__API__Modularized__Scheduler.html#ga8efad6df3a5b036619ea5c76fe50a0c5":[6,22,52],
"group__API__Modularized__Scheduler.html#ga90dfe435a72d46bd23ddaffa287833c2":[6,22,40],
"group__API__Modularized__Scheduler.html#ga966aaa040948551bede3ee46c9f8847e":[6,22,18],
"group__API__Modularized__Scheduler.html#ga9bfbf9eb07c5ccc7c77a40ddb37056b8":[6,22,68],
"group__API__Modularized__Scheduler.html#ga9ed484d5707136420880285afe55bd3d":[6,22,44],
"group__API__Modularized__Scheduler.html#gaa207453a69f029b2f3c74bc8b9cffde2":[6,22,70],
"group__API__Modularized__Scheduler.html#gaa838921844068ca3190dca5e2b5a99db":[6,22,13],
"group__API__Modularized__Scheduler.html#gaab8471a2921b0508b9269b08ecfba3b7":[6,22,43],
"group__API__Modularized__Scheduler.html#gab17420484cfb68122d986d1feee91905":[6,22,77],
"group__API__Modularized__Scheduler.html#gab40975877d0c861348ccc96602be2cae":[6,22,26],
"group__API__Modularized__Scheduler.html#gab8540c0e69c3af17c424944af9b3c802":[6,22,28],
"group__API__Modularized__Scheduler.html#gabd7a0274979659050496fcc1c66b7a1c":[6,22,8],
"group__API__Modularized__Scheduler.html#gabf51817bd8f2a32af327d90eb5d126ec":[6,22,55],
"group__API__Modularized__Scheduler.html#gac3ab95326f770ecd208a9949d18ceddf":[6,22,66],
"group__API__Modularized__Scheduler.html#gac863df9e289543dcfd6a0b5e4e60432a":[6,22,23],
"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c":[6,22,74],
"group__API__Modularized__Scheduler.html#gad06fa143512ae761c452bf0adf685bae":[6,22,54],
"group__API__Modularized__Scheduler.html#gad0e17cdc3def6bd7e9a9a17437969bdb":[6,22,19],
"group__API__Modularized__Scheduler.html#gad76ac70069357b5a3d0ac0a1489016a2":[6,22,69],
"group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd":[6,22,16],
"group__API__Modularized__Scheduler.html#gae1ac4bb35944de31705ba297aef1f9a1":[6,22,50],
"group__API__Modularized__Scheduler.html#gae4532cd31d9d069b810bdf52db2e052e":[6,22,15],
"group__API__Modularized__Scheduler.html#gae4fc13eee5dd3528951a5cfea33c03ce":[6,22,12],
"group__API__Modularized__Scheduler.html#gae97d6b25d8143ef2f7b6260c6f550c5c":[6,22,32],
"group__API__Modularized__Scheduler.html#gaec7ff28a32f69a93850a1233a1c2725f":[6,22,35],
"group__API__Modularized__Scheduler.html#gafb485fe5fb1f46c7ce7eb505815f306b":[6,22,9],
"group__API__Modularized__Scheduler.html#gafb5ce04aff2175aed3763a72bf252107":[6,22,20],
"group__API__Modularized__Scheduler.html#gafb683e254b5084a1321a21fde5139b01":[6,22,53],
"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea27934b03d9ff6827b318124ff683fb40":[6,22,26,0],
"group__API__Modularized__Scheduler.html#ggab40975877d0c861348ccc96602be2caea40dba09874d6d3a220669e0ccea27da2":[6,22,26,1],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component":[6,22,0],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__fifo__data":[6,22,2],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__heteroprio__data":[6,22,5],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data":[6,22,4],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__perfmodel__select__data":[6,22,6],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__prio__data":[6,22,3],
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__specs":[6,22,7],
"group__API__Modularized__Scheduler.html#structstarpu__sched__tree":[6,22,1],
"group__API__OpenCL__Extensions.html":[6,15],
"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297":[6,15,0,0],
"group__API__OpenCL__Extensions.html#ga002e85a0f6bcd087df54287de5ae5e07":[6,15,30],
"group__API__OpenCL__Extensions.html#ga03f34ac98495afc5d0f268e366f80598":[6,15,15],
"group__API__OpenCL__Extensions.html#ga06f19c27ac5147607acc511d49302321":[6,15,26],
"group__API__OpenCL__Extensions.html#ga160dc78c0f6a90b5aa2200b49c5b4d7b":[6,15,1],
"group__API__OpenCL__Extensions.html#ga1b591248c13dc33e2e9b00ace593405e":[6,15,3],
"group__API__OpenCL__Extensions.html#ga1d06b6c00b15f4fcd8d4c0c998f955ac":[6,15,21],
"group__API__OpenCL__Extensions.html#ga23fa324d87f923f39f05bfdc9d3fe7e9":[6,15,6],
"group__API__OpenCL__Extensions.html#ga2708694c061fd89272b0355bcaac11df":[6,15,27],
"group__API__OpenCL__Extensions.html#ga2bd30ada22e761a6b889f0661b54592f":[6,15,29],
"group__API__OpenCL__Extensions.html#ga3441dd1c6e61717dd81a3a6eb0bf75a8":[6,15,18],
"group__API__OpenCL__Extensions.html#ga6680ed21ce09f073fa0256169f4e4868":[6,15,5],
"group__API__OpenCL__Extensions.html#ga68adf424491ec715e891000fa4a6030d":[6,15,22],
"group__API__OpenCL__Extensions.html#ga7ad0ab374a65417ae3d3a9ceed8f24c4":[6,15,7],
"group__API__OpenCL__Extensions.html#ga7dd3784262c0be223394bc8c2fe81935":[6,15,13],
"group__API__OpenCL__Extensions.html#ga7f8e1507dec24eaa7427923bbacb873f":[6,15,24],
"group__API__OpenCL__Extensions.html#ga80f968f210417eb9fbf2bfe82e1953a9":[6,15,12],
"group__API__OpenCL__Extensions.html#ga8318641373e06a2a635cb3ab377c5994":[6,15,9],
"group__API__OpenCL__Extensions.html#ga84a524eaac758722f083ee129a19a567":[6,15,8],
"group__API__OpenCL__Extensions.html#ga893f462bfed53eff3a54f341488db7ad":[6,15,17],
"group__API__OpenCL__Extensions.html#ga95184b2188d67976e00bcb4637ac1933":[6,15,31],
"group__API__OpenCL__Extensions.html#ga9768e086b947961c9db5199e676f05db":[6,15,19],
"group__API__OpenCL__Extensions.html#ga9a1331f26cc54a1f5406770f68b95d29":[6,15,28],
"group__API__OpenCL__Extensions.html#ga9e0073e4c839eec6096f6eeca21d7e36":[6,15,25],
"group__API__OpenCL__Extensions.html#gaa38e7cb3231ed30303e50f46c8f6e39c":[6,15,20],
"group__API__OpenCL__Extensions.html#gab43c1f30361aaa72ca98a9a9fdec792b":[6,15,11],
"group__API__OpenCL__Extensions.html#gababf3ee0552f34c89fdc8ebdec116dbf":[6,15,2],
"group__API__OpenCL__Extensions.html#gac543428352d04b3ff8f735cfc71c3b99":[6,15,16],
"group__API__OpenCL__Extensions.html#gad18d6a0dfbfadcb0fe0b2be6294aa87d":[6,15,10],
"group__API__OpenCL__Extensions.html#gadc4689d1ad238ba0b296e205e3bb6317":[6,15,14],
"group__API__OpenCL__Extensions.html#gae023af317c4040f926d2c50a8f96b5d2":[6,15,4],
"group__API__OpenCL__Extensions.html#gaeaabc8e5d90531a21a8307c06c659984":[6,15,23],
"group__API__OpenCL__Extensions.html#structstarpu__opencl__program":[6,15,0],
"group__API__OpenMP__Runtime__Support.html":[6,21],
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27":[6,21,2,6],
"group__API__OpenMP__Runtime__Support.html#a4f4e595f12101bbace47d4748d6d3e3b":[6,21,3,0],
"group__API__OpenMP__Runtime__Support.html#a594489c9f845922d685046c25f5540e8":[6,21,3,3],
"group__API__OpenMP__Runtime__Support.html#a6e3c542eac204dd67f343427c8a0a17c":[6,21,3,8],
"group__API__OpenMP__Runtime__Support.html#a782139c5c2358477059af82135f76cc2":[6,21,3,9],
"group__API__OpenMP__Runtime__Support.html#a983c8209cef872e2798c2fee32012195":[6,21,2,0],
"group__API__OpenMP__Runtime__Support.html#a9886b8bade17a2e0c32bb2b36cb6c392":[6,21,3,1],
"group__API__OpenMP__Runtime__Support.html#ab4a1aab4aa59767666547ff12a5374a2":[6,21,1,0],
"group__API__OpenMP__Runtime__Support.html#ab804599e2d1ce232830954dbdf3ed886":[6,21,2,3],
"group__API__OpenMP__Runtime__Support.html#abb648c16a9ec65f2834cf05994b33df2":[6,21,3,7],
"group__API__OpenMP__Runtime__Support.html#acd7ec3b07eded637a0c9de5df3192e87":[6,21,2,2],
"group__API__OpenMP__Runtime__Support.html#acf0b820ff6649f9290dbfa3d270d8cec":[6,21,2,1],
"group__API__OpenMP__Runtime__Support.html#acfc22eabce32bfa73fd5020f275c3cf2":[6,21,0,0],
"group__API__OpenMP__Runtime__Support.html#ad64a8be227ee0a2c4ea8fa2eca3d20c0":[6,21,3,4],
"group__API__OpenMP__Runtime__Support.html#ad7d88a7759aade7ae379a88eb737993b":[6,21,3,2],
"group__API__OpenMP__Runtime__Support.html#ae97da9038c9a034dc8734ae4c34ebc21":[6,21,3,6],
"group__API__OpenMP__Runtime__Support.html#aea66f9b4181afb2e4b4c799a09d8a4f0":[6,21,2,4],
"group__API__OpenMP__Runtime__Support.html#aecf5779017beb31e13424202f9dc013b":[6,21,2,5],
"group__API__OpenMP__Runtime__Support.html#afa30d3c752ab9665112df925a39cb4ab":[6,21,3,5],
"group__API__OpenMP__Runtime__Support.html#ga05ecbf96c69f19525730f46d49d92937":[6,21,50],
"group__API__OpenMP__Runtime__Support.html#ga0a2d26b924681a81e92562edf7fa6742":[6,21,26],
"group__API__OpenMP__Runtime__Support.html#ga0a86f6a9d780b564dae9b9a71cfe5e19":[6,21,4],
"group__API__OpenMP__Runtime__Support.html#ga0ae276c0004d0e148e5b85c5262d4f1b":[6,21,38],
"group__API__OpenMP__Runtime__Support.html#ga0fb5be52e8f7630a4f24c2e844a22519":[6,21,79],
"group__API__OpenMP__Runtime__Support.html#ga1080ae6a620b2c40c71311df32ab44d4":[6,21,29],
"group__API__OpenMP__Runtime__Support.html#ga1118d277474ac2dc1a22bf6ef4c59fa9":[6,21,46],
"group__API__OpenMP__Runtime__Support.html#ga13f5e9162e12620fb814627d6eb5e1e8":[6,21,39],
"group__API__OpenMP__Runtime__Support.html#ga1a6d1009b6ff1f68617ade03554d03f3":[6,21,55],
"group__API__OpenMP__Runtime__Support.html#ga1b1d7573040775370ffd49b7accad0f2":[6,21,68],
"group__API__OpenMP__Runtime__Support.html#ga1b951f0922d794e6deb2579c81bcf41b":[6,21,54],
"group__API__OpenMP__Runtime__Support.html#ga2c2739d7b7a1702540b878684b8e4e9b":[6,21,24],
"group__API__OpenMP__Runtime__Support.html#ga2c980c583e9faf124b4446fa90b5ece9":[6,21,37],
"group__API__OpenMP__Runtime__Support.html#ga2cb37eec19b8a24242819e666ecea8fc":[6,21,56],
"group__API__OpenMP__Runtime__Support.html#ga2f1f0d70df3de43bf9069eb4c2e1ca9f":[6,21,15],
"group__API__OpenMP__Runtime__Support.html#ga33af06875785da29f3988d3a985e99f8":[6,21,5],
"group__API__OpenMP__Runtime__Support.html#ga343f59fea8ebbd23c73fcac25571ca20":[6,21,21],
"group__API__OpenMP__Runtime__Support.html#ga3be0d3b2145764db53eb59001ac74e2b":[6,21,10],
"group__API__OpenMP__Runtime__Support.html#ga3cc840689933be3d9e7952eb76e0f44e":[6,21,43],
"group__API__OpenMP__Runtime__Support.html#ga3e01e75c8088bfcd0c4cf366255270b9":[6,21,88],
"group__API__OpenMP__Runtime__Support.html#ga409d48dc7e7158cb7cbdaca31a4b0a27":[6,21,65],
"group__API__OpenMP__Runtime__Support.html#ga41d9b4f1e57c02d34c4bd6e53469c3fc":[6,21,9],
"group__API__OpenMP__Runtime__Support.html#ga42bab9716f59c25ded885f5966fea112":[6,21,40],
"group__API__OpenMP__Runtime__Support.html#ga444e5466c7f457ace4e9aa78cf27e6ef":[6,21,78],
"group__API__OpenMP__Runtime__Support.html#ga478c43dbbdd549ebe481610fd42e1b92":[6,21,58],
"group__API__OpenMP__Runtime__Support.html#ga51dbabbff069511b043833847fb45f30":[6,21,53],
"group__API__OpenMP__Runtime__Support.html#ga541bb9f73081830e3173cf71d57bee94":[6,21,36],
"group__API__OpenMP__Runtime__Support.html#ga544807d42cb7522f8441f1a499f203d3":[6,21,30],
"group__API__OpenMP__Runtime__Support.html#ga5790ead92feacb71e3882de730170b05":[6,21,18],
"group__API__OpenMP__Runtime__Support.html#ga58fb716554b6a79a3207ba114c49abdb":[6,21,74],
"group__API__OpenMP__Runtime__Support.html#ga5a6c050bf14b81d49716946d68e1d7f9":[6,21,66],
"group__API__OpenMP__Runtime__Support.html#ga63f94bc02b7c56c48bd3cbd0a38796ee":[6,21,67],
"group__API__OpenMP__Runtime__Support.html#ga650f12381df2c525c058e6c137930e50":[6,21,31],
"group__API__OpenMP__Runtime__Support.html#ga6551d8b2707c8808c78eb97955928bc8":[6,21,23],
"group__API__OpenMP__Runtime__Support.html#ga6561f2bb3fd370901216986ae8692cc7":[6,21,34],
"group__API__OpenMP__Runtime__Support.html#ga698809a6ff7858a8f26e96635b5efd7e":[6,21,25],
"group__API__OpenMP__Runtime__Support.html#ga6b853eff054548fbf4d97e3607b22315":[6,21,61],
"group__API__OpenMP__Runtime__Support.html#ga706d36f77512013d4e98e8f42da02ff3":[6,21,86],
"group__API__OpenMP__Runtime__Support.html#ga7082f9fb91da015537bf7e65611c9db6":[6,21,20],
"group__API__OpenMP__Runtime__Support.html#ga7d6a35f049f4c449c02680f480239754":[6,21,45],
"group__API__OpenMP__Runtime__Support.html#ga7fc31c012647da08d24fd51e30c5634c":[6,21,64],
"group__API__OpenMP__Runtime__Support.html#ga811381d58ae0a4eb1fced04064150af5":[6,21,71],
"group__API__OpenMP__Runtime__Support.html#ga82292171a04e7de120b878ea52e32bd6":[6,21,33],
"group__API__OpenMP__Runtime__Support.html#ga82338737b7712d171bbbf6125bac33d3":[6,21,28],
"group__API__OpenMP__Runtime__Support.html#ga846b449fccf725b83acf1c3b14f3c740":[6,21,51],
"group__API__OpenMP__Runtime__Support.html#ga86414f0d5062cf47d64b0599bcdd1ccf":[6,21,83],
"group__API__OpenMP__Runtime__Support.html#ga87ac656ff5b1e6b59481a9668a43c669":[6,21,63],
"group__API__OpenMP__Runtime__Support.html#ga8969523514417ac253a9007ffb1eabe0":[6,21,73],
"group__API__OpenMP__Runtime__Support.html#ga896cbd300cf111eb09251995b0576533":[6,21,22],
"group__API__OpenMP__Runtime__Support.html#ga8bc9734bc0f9fb5485b4708b4f3ea219":[6,21,87],
"group__API__OpenMP__Runtime__Support.html#ga8c913c32ba007ce53cd3c3cfcecf2342":[6,21,80],
"group__API__OpenMP__Runtime__Support.html#ga8de196a9b2248ee34f9183a081da8be5":[6,21,49],
"group__API__OpenMP__Runtime__Support.html#ga906913c3eb454506682a130c6bcd6337":[6,21,48],
"group__API__OpenMP__Runtime__Support.html#ga9db57e7c1c67a02837b279145fb1883d":[6,21,16],
"group__API__OpenMP__Runtime__Support.html#ga9f66990dcc824f3078afbba559817c8d":[6,21,13],
"group__API__OpenMP__Runtime__Support.html#gaa15212ca3137d7aba827794b26fee9e0":[6,21,44],
"group__API__OpenMP__Runtime__Support.html#gaa3127cc9d95397b4f066cef20f9ef99d":[6,21,17],
"group__API__OpenMP__Runtime__Support.html#gaa4b70af0a6cf757e05e300c5eeea0a46":[6,21,8],
"group__API__OpenMP__Runtime__Support.html#gaa5c38dfec313088ca5e527a97f40969d":[6,21,7],
"group__API__OpenMP__Runtime__Support.html#gaa63576df9729394a3d53137d7021bab5":[6,21,35],
"group__API__OpenMP__Runtime__Support.html#gaa862fb6fec908c7707daa274ae5950bd":[6,21,90],
"group__API__OpenMP__Runtime__Support.html#gaac482422d2b9bc26c1877f49eaa5fca2":[6,21,57],
"group__API__OpenMP__Runtime__Support.html#gaaf0d71971d1ab1b0d4f9919830693d98":[6,21,14],
"group__API__OpenMP__Runtime__Support.html#gab2727bdd191a5d1c495dc01ccf9872f0":[6,21,82],
"group__API__OpenMP__Runtime__Support.html#gab77e220adc13d13b4d0db0e1df83a2a9":[6,21,72],
"group__API__OpenMP__Runtime__Support.html#gabba6e6a047b80568ba0c98d725290650":[6,21,77],
"group__API__OpenMP__Runtime__Support.html#gabbd8c55707eb2173324c7dcfe04832f3":[6,21,47],
"group__API__OpenMP__Runtime__Support.html#gabe2275b4c4295825181e559affb6dcf2":[6,21,19],
"group__API__OpenMP__Runtime__Support.html#gac9279b86d3c79fc918856bf1f9cde7d6":[6,21,12],
"group__API__OpenMP__Runtime__Support.html#gac9613ed1365bf0db54b6225a1d2c6124":[6,21,11],
"group__API__OpenMP__Runtime__Support.html#gacc6078a78820c367f07d37da11c04520":[6,21,6],
"group__API__OpenMP__Runtime__Support.html#gacc9c3792ea07d0bf694d8b0c8b8c5fb7":[6,21,41],
"group__API__OpenMP__Runtime__Support.html#gad5443806d2ebda1277cc1a64b7b9c357":[6,21,89],
"group__API__OpenMP__Runtime__Support.html#gad7e1721d31a56f25013cfebd97e08690":[6,21,59],
"group__API__OpenMP__Runtime__Support.html#gad8189d962807a8504a5fad8cc2bf58ba":[6,21,84],
"group__API__OpenMP__Runtime__Support.html#gad8abcefdd1731fe8269d833e8103a945":[6,21,27],
"group__API__OpenMP__Runtime__Support.html#gadaf4576512b9ecc58c71cb36a87105b7":[6,21,32],
"group__API__OpenMP__Runtime__Support.html#gadca05b4b67afb0c82cdd39c4773b8fce":[6,21,75],
"group__API__OpenMP__Runtime__Support.html#gae134345a048428661b344b671155cdd9":[6,21,42],
"group__API__OpenMP__Runtime__Support.html#gae79ec9c5fc3150ae926609d10f5aaf05":[6,21,60],
"group__API__OpenMP__Runtime__Support.html#gaede763d0f3b47343eb1a5e64ceec0062":[6,21,70],
"group__API__OpenMP__Runtime__Support.html#gaedec99a0472438a5da0c014a47087878":[6,21,85],
"group__API__OpenMP__Runtime__Support.html#gaf10e0605a1e495ce5bec31dc48dee8d7":[6,21,91],
"group__API__OpenMP__Runtime__Support.html#gaf704c62ed129ed488c4bfd3567ef244d":[6,21,81],
"group__API__OpenMP__Runtime__Support.html#gaf820ec6afd10011a711cfe1140f2789c":[6,21,76],
"group__API__OpenMP__Runtime__Support.html#gaf9dadc1e3add021b130b014f156abd9e":[6,21,62],
"group__API__OpenMP__Runtime__Support.html#gafe303ff7d26bcd668959ee967eedda97":[6,21,52],
"group__API__OpenMP__Runtime__Support.html#gaff3980856fe3f8ebded80d72ef13ab78":[6,21,69],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8a02777843a2c5b974de09ea8bcf32e941":[6,21,5,1],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8a87a991db4d890f5b392916cd5c13e2e2":[6,21,5,0],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8a92f0f38f4e63ce4e92bbaed2f05ede46":[6,21,5,4],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8ac0ed3cabe793db8c5bfb3b37699f735f":[6,21,5,3],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8acf3b83c917898faba661fbd59862ee74":[6,21,5,5],
"group__API__OpenMP__Runtime__Support.html#gga33af06875785da29f3988d3a985e99f8ad3dca1019208722703d09ab2bc6e773a":[6,21,5,2],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a1bd6f1e299e1ecbcda4ba3a515ff24a6":[6,21,6,1],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a388a8bb9eea70a251880ad2feb7ed738":[6,21,6,5],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a3d9743c37c602cda1f4338c4ecb205aa":[6,21,6,2],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a6fff0f1f63848cab0e03487f0c4ae30d":[6,21,6,3],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a8559aa5493b48f068f966c3317f941b1":[6,21,6,4],
"group__API__OpenMP__Runtime__Support.html#ggacc6078a78820c367f07d37da11c04520a92f5c1a1ada9cce708db9d0062db8486":[6,21,6,0],
"group__API__OpenMP__Runtime__Support.html#structstarpu__omp__lock__t":[6,21,0],
"group__API__OpenMP__Runtime__Support.html#structstarpu__omp__nest__lock__t":[6,21,1],
"group__API__OpenMP__Runtime__Support.html#structstarpu__omp__parallel__region__attr":[6,21,2],
"group__API__OpenMP__Runtime__Support.html#structstarpu__omp__task__region__attr":[6,21,3],
"group__API__Out__Of__Core.html":[6,31],
"group__API__Out__Of__Core.html#a00b4fbe01a33b0f2526bd70e8128dfbd":[6,31,0,6],
"group__API__Out__Of__Core.html#a18216c9db1b888e568af638dbb22b16f":[6,31,0,7],
"group__API__Out__Of__Core.html#a19b47927d234281d157b9191c9f59d57":[6,31,0,4],
"group__API__Out__Of__Core.html#a1c98a8168c9f6046cc3c374d13c2f9d8":[6,31,0,15],
"group__API__Out__Of__Core.html#a217c4a50625fa3489ff9fde9259b020e":[6,31,0,11],
"group__API__Out__Of__Core.html#a3ff4d322bb04025abb4a23638f4594a6":[6,31,0,0],
"group__API__Out__Of__Core.html#a4831b8088a13f038e267e9b141af4283":[6,31,0,10],
"group__API__Out__Of__Core.html#a60d61aa8464bc852d6f4d118f70cb44f":[6,31,0,5],
"group__API__Out__Of__Core.html#a61b0e51977bdc6cc20d75f7c3ff2d614":[6,31,0,3],
"group__API__Out__Of__Core.html#a67804045d2c3a3e240ec152090885853":[6,31,0,14],
"group__API__Out__Of__Core.html#a6c89ac6cf13a6eec0eb36491d5b8ce8f":[6,31,0,17],
"group__API__Out__Of__Core.html#a728c7a6e4c919a72300ac8f8a3bae0b2":[6,31,0,2],
"group__API__Out__Of__Core.html#aa9c45355d7c609a9deccd366fab8ab5b":[6,31,0,9],
"group__API__Out__Of__Core.html#aaaff065edbd1ad085acc89352cafd253":[6,31,0,1],
"group__API__Out__Of__Core.html#ab2317c0bff32b2b338632c70d56466c6":[6,31,0,13],
"group__API__Out__Of__Core.html#ad76930b8488dbedad92de1b5368dbdc8":[6,31,0,18],
"group__API__Out__Of__Core.html#ae0d4c45de6fe688d86f234884d26f4e0":[6,31,0,12],
"group__API__Out__Of__Core.html#ae1c30bb72265e8d1e972bfb00cf6345e":[6,31,0,16],
"group__API__Out__Of__Core.html#af8075b45d01d4b6a556644aed724a999":[6,31,0,8],
"group__API__Out__Of__Core.html#ga0a32ef9e11531938948f332ffc06feac":[6,31,5],
"group__API__Out__Of__Core.html#ga2df434587aeeaaf16a116163eb690a2d":[6,31,1],
"group__API__Out__Of__Core.html#ga5088eabf3181fc0d2516ec617f04b449":[6,31,8],
"group__API__Out__Of__Core.html#ga8cd566efd70ad57cda18a6b9a7be4ac7":[6,31,2],
"group__API__Out__Of__Core.html#ga9c2e0c65181779e0d4ca2231df3ac03e":[6,31,7],
"group__API__Out__Of__Core.html#gac0234716edb5f73e6f46288f9017d605":[6,31,10],
"group__API__Out__Of__Core.html#gac9ed48246cb2b326ca6a199b6183aa75":[6,31,4],
"group__API__Out__Of__Core.html#gad75ff93c36fc85e172a5f4057b07f091":[6,31,9],
"group__API__Out__Of__Core.html#gada0fb9813aab8ff529ca1881f9b4943e":[6,31,6],
"group__API__Out__Of__Core.html#gaddcdc1beb6f41ed8d38778fb51cc0e6d":[6,31,3],
"group__API__Out__Of__Core.html#structstarpu__disk__ops":[6,31,0],
"group__API__Parallel__Tasks.html":[6,19],
"group__API__Parallel__Tasks.html#ga176c8b45655615fbd09f0b70ba8b78b5":[6,19,5],
"group__API__Parallel__Tasks.html#ga3d362cb0de1da4e2659f602eff325479":[6,19,8],
"group__API__Parallel__Tasks.html#ga49a6732f413550652450baa64594bc5e":[6,19,0],
"group__API__Parallel__Tasks.html#ga4eb5aaf2f4e0c9a7f07cbc80f3ae9664":[6,19,4],
"group__API__Parallel__Tasks.html#ga573d2513a10cf1d14fee0467eda0884d":[6,19,3],
"group__API__Parallel__Tasks.html#ga5b81d2b58b724e33b7fcbb546464510a":[6,19,1],
"group__API__Parallel__Tasks.html#ga720a70f5297ffe3b5ea5cf6eff549c8c":[6,19,6],
"group__API__Parallel__Tasks.html#gae3fe82c940e36715145baa9fe003e453":[6,19,7],
"group__API__Parallel__Tasks.html#gae53499613fb72e9aa1abad6437a926f9":[6,19,2]
};
